#include <vdr/osdbase.h>

class cPvr350Osd : public cOsdBase {
private:
    int  fd;
    unsigned char *osd;
    int  xoff;
    int  yoff;
    bool m_ShownWindows[MAXNUMWINDOWS];

public:
    cPvr350Osd(int fd, unsigned char *buf,int X, int Y);
    ~cPvr350Osd();
    virtual bool OpenWindow(cWindow *Window);
    virtual void CommitWindow(cWindow *Window);
    virtual void ShowWindow(cWindow *Window);
    virtual void HideWindow(cWindow *Window, bool Hide);
    virtual void CloseWindow(cWindow *Window);
    virtual void MoveWindow(cWindow *Window, int x, int y);
};
